package com.ruoyi.cms.service;

import java.util.HashMap;
import java.util.List;

import com.ruoyi.cms.domain.Job;
import com.ruoyi.cms.domain.JobApply;
import com.ruoyi.cms.domain.vo.CandidateVO;
import com.ruoyi.common.core.domain.entity.AppUser;

/**
 * 岗位申请Service接口
 * 
 * @author lishundong
 * @date 2024-09-04
 */
public interface IJobApplyService 
{
    /**
     * 查询岗位申请
     * 
     * @param id 岗位申请主键
     * @return 岗位申请
     */
    public JobApply selectJobApplyById(Long id);

    /**
     * 查询岗位申请列表
     * 
     * @param jobApply 岗位申请
     * @return 岗位申请集合
     */
    public List<JobApply> selectJobApplyList(JobApply jobApply);

    /**
     * 新增岗位申请
     * 
     * @param jobApply 岗位申请
     * @return 结果
     */
    public int insertJobApply(JobApply jobApply);

    /**
     * 修改岗位申请
     * 
     * @param jobApply 岗位申请
     * @return 结果
     */
    public int updateJobApply(JobApply jobApply);

    /**
     * 批量删除岗位申请
     * 
     * @param ids 需要删除的岗位申请主键集合
     * @return 结果
     */
    public int deleteJobApplyByIds(Long[] ids);

    List<Job> applyJob();

    HashMap<String, Integer> statistics();

    HashMap<String,Integer> trendChart(JobApply jobApply);

    List<CandidateVO> selectAppUserList(Job job);

    List<CandidateVO> selectApplyJobUserList(AppUser appUser);


    public int applyComJob(JobApply jobApply);

    public List<Job> selectJobApplyListJob(JobApply jobApply);

    public int updateJobZphApply(JobApply jobApply);

    public int applyJobCencal(JobApply jobApply);

    public List<Job> selectCencalList(JobApply jobApply);
}
